@@ -21,6 +21,8 @@ logger = logging.getLogger(__name__)
 # set_state() on a pipeline.
 gst_logger = logging.getLogger('mopidy.audio.gst')
 
+_GST_PLAY_FLAGS_AUDIO = 0x02
+
 _GST_STATE_MAPPING = {
     Gst.State.PLAYING: PlaybackState.PLAYING,
     Gst.State.PAUSED: PlaybackState.PAUSED,
@@ -366,12 +368,16 @@ class _Handler(object):
 
         # Emit any postponed tags that we got after about-to-finish.
         tags, self._audio._pending_tags = self._audio._pending_tags, None
-        self._audio._tags = tags
+        self._audio._tags = tags or {}
 
         if tags:
             logger.debug('Audio event: tags_changed(tags=%r)', tags.keys())
             AudioListener.send('tags_changed', tags=tags.keys())
 
+        if self._audio._pending_metadata:
+            self._audio._playbin.send_event(self._audio._pending_metadata)
+            self._audio._pending_metadata = None
+
     def on_segment(self, segment):
         gst_logger.debug(
             'Got SEGMENT pad event: '
@@ -410,6 +416,7 @@ class Audio(pykka.ThreadingActor):
         self._tags = {}
         self._pending_uri = None
         self._pending_tags = None
+        self._pending_metadata = None
 
         self._playbin = None
         self._outputs = None
@@ -448,7 +455,7 @@ class Audio(pykka.ThreadingActor):
 
     def _setup_playbin(self):
         playbin = Gst.ElementFactory.make('playbin')
-        playbin.set_property('flags', 2)  # GST_PLAY_FLAG_AUDIO
+        playbin.set_property('flags', _GST_PLAY_FLAGS_AUDIO)
 
         # TODO: turn into config values...
         playbin.set_property('buffer-size', 5 << 20)  # 5MB
@@ -485,15 +492,16 @@ class Audio(pykka.ThreadingActor):
 
     def _setup_audio_sink(self):
         audio_sink = Gst.ElementFactory.make('bin', 'audio-sink')
+        queue = Gst.ElementFactory.make('queue')
+        volume = Gst.ElementFactory.make('volume')
 
         # Queue element to buy us time between the about-to-finish event and
         # the actual switch, i.e. about to switch can block for longer thanks
         # to this queue.
+
         # TODO: See if settings should be set to minimize latency. Previous
         # setting breaks appsrc, and settings before that broke on a few
         # systems. So leave the default to play it safe.
-        queue = Gst.ElementFactory.make('queue')
-
         if self._config['audio']['buffer_time'] > 0:
             queue.set_property(
                 'max-size-time',
@@ -501,15 +509,13 @@ class Audio(pykka.ThreadingActor):
 
         audio_sink.add(queue)
         audio_sink.add(self._outputs)
+        audio_sink.add(volume)
+
+        queue.link(volume)
+        volume.link(self._outputs)
 
         if self.mixer:
-            volume = Gst.ElementFactory.make('volume')
-            audio_sink.add(volume)
-            queue.link(volume)
-            volume.link(self._outputs)
             self.mixer.setup(volume, self.actor_ref.proxy().mixer)
-        else:
-            queue.link(self._outputs)
 
         ghost_pad = Gst.GhostPad.new('sink', queue.get_static_pad('sink'))
         audio_sink.add_pad(ghost_pad)
@@ -803,8 +809,10 @@ class Audio(pykka.ThreadingActor):
             'Sending TAG event for track %r: %r',
             track.uri, taglist.to_string())
         event = Gst.Event.new_tag(taglist)
-        # TODO: check if we get this back on our own bus?
-        self._playbin.send_event(event)
+        if self._pending_uri:
+            self._pending_metadata = event
+        else:
+            self._playbin.send_event(event)
 
     def get_current_tags(self):
         """
