@@ -51,7 +51,7 @@ class ConnectionTest(unittest.TestCase):
 
         network.Connection.__init__(
             self.mock, protocol, protocol_kwargs, sock, addr, sentinel.timeout)
-        self.assertEqual(sock, self.mock.sock)
+        self.assertEqual(sock, self.mock._sock)
         self.assertEqual(protocol, self.mock.protocol)
         self.assertEqual(protocol_kwargs, self.mock.protocol_kwargs)
         self.assertEqual(sentinel.timeout, self.mock.timeout)
@@ -73,7 +73,7 @@ class ConnectionTest(unittest.TestCase):
     def test_stop_disables_recv_send_and_timeout(self):
         self.mock.stopping = False
         self.mock.actor_ref = Mock()
-        self.mock.sock = Mock(spec=socket.SocketType)
+        self.mock._sock = Mock(spec=socket.SocketType)
 
         network.Connection.stop(self.mock, sentinel.reason)
         self.mock.disable_timeout.assert_called_once_with()
@@ -83,24 +83,24 @@ class ConnectionTest(unittest.TestCase):
     def test_stop_closes_socket(self):
         self.mock.stopping = False
         self.mock.actor_ref = Mock()
-        self.mock.sock = Mock(spec=socket.SocketType)
+        self.mock._sock = Mock(spec=socket.SocketType)
 
         network.Connection.stop(self.mock, sentinel.reason)
-        self.mock.sock.close.assert_called_once_with()
+        self.mock._sock.close.assert_called_once_with()
 
     def test_stop_closes_socket_error(self):
         self.mock.stopping = False
         self.mock.actor_ref = Mock()
-        self.mock.sock = Mock(spec=socket.SocketType)
-        self.mock.sock.close.side_effect = socket.error
+        self.mock._sock = Mock(spec=socket.SocketType)
+        self.mock._sock.close.side_effect = socket.error
 
         network.Connection.stop(self.mock, sentinel.reason)
-        self.mock.sock.close.assert_called_once_with()
+        self.mock._sock.close.assert_called_once_with()
 
     def test_stop_stops_actor(self):
         self.mock.stopping = False
         self.mock.actor_ref = Mock()
-        self.mock.sock = Mock(spec=socket.SocketType)
+        self.mock._sock = Mock(spec=socket.SocketType)
 
         network.Connection.stop(self.mock, sentinel.reason)
         self.mock.actor_ref.stop.assert_called_once_with(block=False)
@@ -109,7 +109,7 @@ class ConnectionTest(unittest.TestCase):
         self.mock.stopping = False
         self.mock.actor_ref = Mock()
         self.mock.actor_ref.stop.side_effect = pykka.ActorDeadError()
-        self.mock.sock = Mock(spec=socket.SocketType)
+        self.mock._sock = Mock(spec=socket.SocketType)
 
         network.Connection.stop(self.mock, sentinel.reason)
         self.mock.actor_ref.stop.assert_called_once_with(block=False)
@@ -117,7 +117,7 @@ class ConnectionTest(unittest.TestCase):
     def test_stop_sets_stopping_to_true(self):
         self.mock.stopping = False
         self.mock.actor_ref = Mock()
-        self.mock.sock = Mock(spec=socket.SocketType)
+        self.mock._sock = Mock(spec=socket.SocketType)
 
         network.Connection.stop(self.mock, sentinel.reason)
         self.assertEqual(True, self.mock.stopping)
@@ -125,17 +125,17 @@ class ConnectionTest(unittest.TestCase):
     def test_stop_does_not_proceed_when_already_stopping(self):
         self.mock.stopping = True
         self.mock.actor_ref = Mock()
-        self.mock.sock = Mock(spec=socket.SocketType)
+        self.mock._sock = Mock(spec=socket.SocketType)
 
         network.Connection.stop(self.mock, sentinel.reason)
         self.assertEqual(0, self.mock.actor_ref.stop.call_count)
-        self.assertEqual(0, self.mock.sock.close.call_count)
+        self.assertEqual(0, self.mock._sock.close.call_count)
 
     @patch.object(network.logger, 'log', new=Mock())
     def test_stop_logs_reason(self):
         self.mock.stopping = False
         self.mock.actor_ref = Mock()
-        self.mock.sock = Mock(spec=socket.SocketType)
+        self.mock._sock = Mock(spec=socket.SocketType)
 
         network.Connection.stop(self.mock, sentinel.reason)
         network.logger.log.assert_called_once_with(
@@ -145,7 +145,7 @@ class ConnectionTest(unittest.TestCase):
     def test_stop_logs_reason_with_level(self):
         self.mock.stopping = False
         self.mock.actor_ref = Mock()
-        self.mock.sock = Mock(spec=socket.SocketType)
+        self.mock._sock = Mock(spec=socket.SocketType)
 
         network.Connection.stop(
             self.mock, sentinel.reason, level=sentinel.level)
@@ -156,7 +156,7 @@ class ConnectionTest(unittest.TestCase):
     def test_stop_logs_that_it_is_calling_itself(self):
         self.mock.stopping = True
         self.mock.actor_ref = Mock()
-        self.mock.sock = Mock(spec=socket.SocketType)
+        self.mock._sock = Mock(spec=socket.SocketType)
 
         network.Connection.stop(self.mock, sentinel.reason)
         network.logger.log(any_int, any_unicode)
@@ -164,8 +164,8 @@ class ConnectionTest(unittest.TestCase):
     @patch.object(GObject, 'io_add_watch', new=Mock())
     def test_enable_recv_registers_with_gobject(self):
         self.mock.recv_id = None
-        self.mock.sock = Mock(spec=socket.SocketType)
-        self.mock.sock.fileno.return_value = sentinel.fileno
+        self.mock._sock = Mock(spec=socket.SocketType)
+        self.mock._sock.fileno.return_value = sentinel.fileno
         GObject.io_add_watch.return_value = sentinel.tag
 
         network.Connection.enable_recv(self.mock)
@@ -177,7 +177,7 @@ class ConnectionTest(unittest.TestCase):
 
     @patch.object(GObject, 'io_add_watch', new=Mock())
     def test_enable_recv_already_registered(self):
-        self.mock.sock = Mock(spec=socket.SocketType)
+        self.mock._sock = Mock(spec=socket.SocketType)
         self.mock.recv_id = sentinel.tag
 
         network.Connection.enable_recv(self.mock)
@@ -185,7 +185,7 @@ class ConnectionTest(unittest.TestCase):
 
     def test_enable_recv_does_not_change_tag(self):
         self.mock.recv_id = sentinel.tag
-        self.mock.sock = Mock(spec=socket.SocketType)
+        self.mock._sock = Mock(spec=socket.SocketType)
 
         network.Connection.enable_recv(self.mock)
         self.assertEqual(sentinel.tag, self.mock.recv_id)
@@ -208,8 +208,8 @@ class ConnectionTest(unittest.TestCase):
 
     def test_enable_recv_on_closed_socket(self):
         self.mock.recv_id = None
-        self.mock.sock = Mock(spec=socket.SocketType)
-        self.mock.sock.fileno.side_effect = socket.error(errno.EBADF, '')
+        self.mock._sock = Mock(spec=socket.SocketType)
+        self.mock._sock.fileno.side_effect = socket.error(errno.EBADF, '')
 
         network.Connection.enable_recv(self.mock)
         self.mock.stop.assert_called_once_with(any_unicode)
@@ -218,8 +218,8 @@ class ConnectionTest(unittest.TestCase):
     @patch.object(GObject, 'io_add_watch', new=Mock())
     def test_enable_send_registers_with_gobject(self):
         self.mock.send_id = None
-        self.mock.sock = Mock(spec=socket.SocketType)
-        self.mock.sock.fileno.return_value = sentinel.fileno
+        self.mock._sock = Mock(spec=socket.SocketType)
+        self.mock._sock.fileno.return_value = sentinel.fileno
         GObject.io_add_watch.return_value = sentinel.tag
 
         network.Connection.enable_send(self.mock)
@@ -231,7 +231,7 @@ class ConnectionTest(unittest.TestCase):
 
     @patch.object(GObject, 'io_add_watch', new=Mock())
     def test_enable_send_already_registered(self):
-        self.mock.sock = Mock(spec=socket.SocketType)
+        self.mock._sock = Mock(spec=socket.SocketType)
         self.mock.send_id = sentinel.tag
 
         network.Connection.enable_send(self.mock)
@@ -239,7 +239,7 @@ class ConnectionTest(unittest.TestCase):
 
     def test_enable_send_does_not_change_tag(self):
         self.mock.send_id = sentinel.tag
-        self.mock.sock = Mock(spec=socket.SocketType)
+        self.mock._sock = Mock(spec=socket.SocketType)
 
         network.Connection.enable_send(self.mock)
         self.assertEqual(sentinel.tag, self.mock.send_id)
@@ -262,8 +262,8 @@ class ConnectionTest(unittest.TestCase):
 
     def test_enable_send_on_closed_socket(self):
         self.mock.send_id = None
-        self.mock.sock = Mock(spec=socket.SocketType)
-        self.mock.sock.fileno.side_effect = socket.error(errno.EBADF, '')
+        self.mock._sock = Mock(spec=socket.SocketType)
+        self.mock._sock.fileno.side_effect = socket.error(errno.EBADF, '')
 
         network.Connection.enable_send(self.mock)
         self.assertEqual(None, self.mock.send_id)
@@ -367,7 +367,7 @@ class ConnectionTest(unittest.TestCase):
         self.assertEqual('', self.mock.send_buffer)
 
     def test_recv_callback_respects_io_err(self):
-        self.mock.sock = Mock(spec=socket.SocketType)
+        self.mock._sock = Mock(spec=socket.SocketType)
         self.mock.actor_ref = Mock()
 
         self.assertTrue(network.Connection.recv_callback(
@@ -375,7 +375,7 @@ class ConnectionTest(unittest.TestCase):
         self.mock.stop.assert_called_once_with(any_unicode)
 
     def test_recv_callback_respects_io_hup(self):
-        self.mock.sock = Mock(spec=socket.SocketType)
+        self.mock._sock = Mock(spec=socket.SocketType)
         self.mock.actor_ref = Mock()
 
         self.assertTrue(network.Connection.recv_callback(
@@ -383,7 +383,7 @@ class ConnectionTest(unittest.TestCase):
         self.mock.stop.assert_called_once_with(any_unicode)
 
     def test_recv_callback_respects_io_hup_and_io_err(self):
-        self.mock.sock = Mock(spec=socket.SocketType)
+        self.mock._sock = Mock(spec=socket.SocketType)
         self.mock.actor_ref = Mock()
 
         self.assertTrue(network.Connection.recv_callback(
@@ -392,8 +392,8 @@ class ConnectionTest(unittest.TestCase):
         self.mock.stop.assert_called_once_with(any_unicode)
 
     def test_recv_callback_sends_data_to_actor(self):
-        self.mock.sock = Mock(spec=socket.SocketType)
-        self.mock.sock.recv.return_value = 'data'
+        self.mock._sock = Mock(spec=socket.SocketType)
+        self.mock._sock.recv.return_value = 'data'
         self.mock.actor_ref = Mock()
 
         self.assertTrue(network.Connection.recv_callback(
@@ -402,8 +402,8 @@ class ConnectionTest(unittest.TestCase):
             {'received': 'data'})
 
     def test_recv_callback_handles_dead_actors(self):
-        self.mock.sock = Mock(spec=socket.SocketType)
-        self.mock.sock.recv.return_value = 'data'
+        self.mock._sock = Mock(spec=socket.SocketType)
+        self.mock._sock.recv.return_value = 'data'
         self.mock.actor_ref = Mock()
         self.mock.actor_ref.tell.side_effect = pykka.ActorDeadError()
 
@@ -412,38 +412,38 @@ class ConnectionTest(unittest.TestCase):
         self.mock.stop.assert_called_once_with(any_unicode)
 
     def test_recv_callback_gets_no_data(self):
-        self.mock.sock = Mock(spec=socket.SocketType)
-        self.mock.sock.recv.return_value = ''
+        self.mock._sock = Mock(spec=socket.SocketType)
+        self.mock._sock.recv.return_value = ''
         self.mock.actor_ref = Mock()
 
         self.assertTrue(network.Connection.recv_callback(
             self.mock, sentinel.fd, GObject.IO_IN))
         self.assertEqual(self.mock.mock_calls, [
-            call.sock.recv(any_int),
+            call._sock.recv(any_int),
             call.disable_recv(),
             call.actor_ref.tell({'close': True}),
         ])
 
     def test_recv_callback_recoverable_error(self):
-        self.mock.sock = Mock(spec=socket.SocketType)
+        self.mock._sock = Mock(spec=socket.SocketType)
 
         for error in (errno.EWOULDBLOCK, errno.EINTR):
-            self.mock.sock.recv.side_effect = socket.error(error, '')
+            self.mock._sock.recv.side_effect = socket.error(error, '')
             self.assertTrue(network.Connection.recv_callback(
                 self.mock, sentinel.fd, GObject.IO_IN))
             self.assertEqual(0, self.mock.stop.call_count)
 
     def test_recv_callback_unrecoverable_error(self):
-        self.mock.sock = Mock(spec=socket.SocketType)
-        self.mock.sock.recv.side_effect = socket.error
+        self.mock._sock = Mock(spec=socket.SocketType)
+        self.mock._sock.recv.side_effect = socket.error
 
         self.assertTrue(network.Connection.recv_callback(
             self.mock, sentinel.fd, GObject.IO_IN))
         self.mock.stop.assert_called_once_with(any_unicode)
 
     def test_send_callback_respects_io_err(self):
-        self.mock.sock = Mock(spec=socket.SocketType)
-        self.mock.sock.send.return_value = 1
+        self.mock._sock = Mock(spec=socket.SocketType)
+        self.mock._sock.send.return_value = 1
         self.mock.send_lock = Mock()
         self.mock.actor_ref = Mock()
         self.mock.send_buffer = ''
@@ -453,8 +453,8 @@ class ConnectionTest(unittest.TestCase):
         self.mock.stop.assert_called_once_with(any_unicode)
 
     def test_send_callback_respects_io_hup(self):
-        self.mock.sock = Mock(spec=socket.SocketType)
-        self.mock.sock.send.return_value = 1
+        self.mock._sock = Mock(spec=socket.SocketType)
+        self.mock._sock.send.return_value = 1
         self.mock.send_lock = Mock()
         self.mock.actor_ref = Mock()
         self.mock.send_buffer = ''
@@ -464,8 +464,8 @@ class ConnectionTest(unittest.TestCase):
         self.mock.stop.assert_called_once_with(any_unicode)
 
     def test_send_callback_respects_io_hup_and_io_err(self):
-        self.mock.sock = Mock(spec=socket.SocketType)
-        self.mock.sock.send.return_value = 1
+        self.mock._sock = Mock(spec=socket.SocketType)
+        self.mock._sock.send.return_value = 1
         self.mock.send_lock = Mock()
         self.mock.actor_ref = Mock()
         self.mock.send_buffer = ''
@@ -479,8 +479,8 @@ class ConnectionTest(unittest.TestCase):
         self.mock.send_lock = Mock()
         self.mock.send_lock.acquire.return_value = True
         self.mock.send_buffer = ''
-        self.mock.sock = Mock(spec=socket.SocketType)
-        self.mock.sock.send.return_value = 0
+        self.mock._sock = Mock(spec=socket.SocketType)
+        self.mock._sock.send.return_value = 0
 
         self.assertTrue(network.Connection.send_callback(
             self.mock, sentinel.fd, GObject.IO_IN))
@@ -491,13 +491,13 @@ class ConnectionTest(unittest.TestCase):
         self.mock.send_lock = Mock()
         self.mock.send_lock.acquire.return_value = False
         self.mock.send_buffer = ''
-        self.mock.sock = Mock(spec=socket.SocketType)
-        self.mock.sock.send.return_value = 0
+        self.mock._sock = Mock(spec=socket.SocketType)
+        self.mock._sock.send.return_value = 0
 
         self.assertTrue(network.Connection.send_callback(
             self.mock, sentinel.fd, GObject.IO_IN))
         self.mock.send_lock.acquire.assert_called_once_with(False)
-        self.assertEqual(0, self.mock.sock.send.call_count)
+        self.assertEqual(0, self.mock._sock.send.call_count)
 
     def test_send_callback_sends_all_data(self):
         self.mock.send_lock = Mock()
@@ -523,31 +523,31 @@ class ConnectionTest(unittest.TestCase):
         self.assertEqual('ta', self.mock.send_buffer)
 
     def test_send_recoverable_error(self):
-        self.mock.sock = Mock(spec=socket.SocketType)
+        self.mock._sock = Mock(spec=socket.SocketType)
 
         for error in (errno.EWOULDBLOCK, errno.EINTR):
-            self.mock.sock.send.side_effect = socket.error(error, '')
+            self.mock._sock.send.side_effect = socket.error(error, '')
 
             network.Connection.send(self.mock, 'data')
             self.assertEqual(0, self.mock.stop.call_count)
 
     def test_send_calls_socket_send(self):
-        self.mock.sock = Mock(spec=socket.SocketType)
-        self.mock.sock.send.return_value = 4
+        self.mock._sock = Mock(spec=socket.SocketType)
+        self.mock._sock.send.return_value = 4
 
         self.assertEqual('', network.Connection.send(self.mock, 'data'))
-        self.mock.sock.send.assert_called_once_with('data')
+        self.mock._sock.send.assert_called_once_with('data')
 
     def test_send_calls_socket_send_partial_send(self):
-        self.mock.sock = Mock(spec=socket.SocketType)
-        self.mock.sock.send.return_value = 2
+        self.mock._sock = Mock(spec=socket.SocketType)
+        self.mock._sock.send.return_value = 2
 
         self.assertEqual('ta', network.Connection.send(self.mock, 'data'))
-        self.mock.sock.send.assert_called_once_with('data')
+        self.mock._sock.send.assert_called_once_with('data')
 
     def test_send_unrecoverable_error(self):
-        self.mock.sock = Mock(spec=socket.SocketType)
-        self.mock.sock.send.side_effect = socket.error
+        self.mock._sock = Mock(spec=socket.SocketType)
+        self.mock._sock.send.side_effect = socket.error
 
         self.assertEqual('', network.Connection.send(self.mock, 'data'))
         self.mock.stop.assert_called_once_with(any_unicode)
